@@ -43,5 +43,9 @@ pub fn log(graph: &Graph<Rc<PullRequest>, usize>) -> FlatDep {
         }
     }
 
+    out.sort_by_key(|(dep, _)| {
+        dep.state().clone()
+    });
+
     out
 }
